@@ -1,6 +1,6 @@
 package App::JobLog::Vacation::Period;
 {
-  $App::JobLog::Vacation::Period::VERSION = '1.029';
+  $App::JobLog::Vacation::Period::VERSION = '1.030';
 }
 
 # ABSTRACT: extension of L<App::JobLog::Log::Event> to handle special properties of vacation periods
@@ -140,7 +140,7 @@ sub parse {
     else {
         carp "malformed line in vacation file: '$text'";
     }
-    return undef;
+    return;
 }
 
 sub _parse_time {
@@ -335,6 +335,7 @@ sub _description {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -343,7 +344,7 @@ App::JobLog::Vacation::Period - extension of L<App::JobLog::Log::Event> to handl
 
 =head1 VERSION
 
-version 1.029
+version 1.030
 
 =head1 DESCRIPTION
 
@@ -428,4 +429,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
